# DeploymentInstanceResource


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | the guid that represents this resource | [optional] 
**type** | **str** | the type of resource | [optional] 
**name** | **str** | a name for this resource | [optional] 
**template_name** | **str** | the name of the template associated with this resource | [optional] 
**shared** | **bool** | The resource is shared among other templates. On destruction of the template, the resource will not be destroyed  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


